==> escudo-0.4.tbz2: escudo-0.4/components/payeesAutoComplete.js <==
/**
 *  This file is part of Escudo.
 *
 *  Escudo is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Escudo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Escudo.  If not, see <http://www.gnu.org/licenses/>.
 */

Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");

function PayeesAutoComplete() {
  //we need to retrieve the top most window, to obtain the root object for escudo
  var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                     .getService(Components.interfaces["nsIWindowMediator"]);
  this.root = wm.getMostRecentWindow("Escudo:Window").top;
}

PayeesAutoComplete.prototype = {
  classDescription: "Escudo payees auto complete",
  classID:          Components.ID("{0e7bff90-0d6c-11de-8c30-0800200c9a67}"),
  contractID:       "@mozilla.org/autocomplete/search;1?name=payees-autocomplete",
  QueryInterface:   XPCOMUtils.generateQI([Components.interfaces.nsIAutoCompleteSearch]),

  startSearch: function(searchString, searchParam, previousResult, listener) {
    var payees = this.root.Escudo.Payees.getPayeesMatchingPattern(searchString);
    var result = {
      results: null,
      defaultIndex: 0,
      errorDescription: null,
      matchCount: 0,
      searchResult: Components.interfaces.nsIAutoCompleteResult.RESULT_SUCCESS,
      searchString: searchString,
      getCommentAt: function(index){},
      getStyleAt: function(index){},
      getImageAt: function(index){},
      getValueAt: function(index){return this.results[index].payee},
      removeValueAt: function(rowIndex, removeFromDb) {}
    }

    result.results = payees;
    result.matchCount = payees.length;
    listener.onSearchResult(this, result);
  },

  stopSearch: function() {}
};

var components = [PayeesAutoComplete];

function NSGetModule(compMgr, fileSpec) {
  return XPCOMUtils.generateModule(components);
}

==> escudo-0.4.1.tbz2: escudo-0.4.1/components/payeesAutoComplete.js <==
/**
 *  This file is part of Escudo.
 *
 *  Escudo is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Escudo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Escudo.  If not, see <http://www.gnu.org/licenses/>.
 */

Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");

function PayeesAutoComplete() {
  //we need to retrieve the top most window, to obtain the root object for escudo
  var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                     .getService(Components.interfaces["nsIWindowMediator"]);
  this.root = wm.getMostRecentWindow("Escudo:Window").top;
}

PayeesAutoComplete.prototype = {
  classDescription: "Escudo payees auto complete",
  classID:          Components.ID("{0e7bff90-0d6c-11de-8c30-0800200c9a67}"),
  contractID:       "@mozilla.org/autocomplete/search;1?name=payees-autocomplete",
  QueryInterface:   XPCOMUtils.generateQI([Components.interfaces.nsIAutoCompleteSearch]),

  startSearch: function(searchString, searchParam, previousResult, listener) {
    var payees = this.root.Escudo.Payees.getPayeesMatchingPattern(searchString);
    var result = {
      results: null,
      defaultIndex: 0,
      errorDescription: null,
      matchCount: 0,
      searchResult: Components.interfaces.nsIAutoCompleteResult.RESULT_SUCCESS,
      searchString: searchString,
      getCommentAt: function(index){},
      getStyleAt: function(index){},
      getImageAt: function(index){},
      getValueAt: function(index){return this.results[index]},
      removeValueAt: function(rowIndex, removeFromDb) {}
    }

    result.results = payees;
    result.matchCount = payees.length;
    listener.onSearchResult(this, result);
  },

  stopSearch: function() {}
};

var components = [PayeesAutoComplete];

function NSGetModule(compMgr, fileSpec) {
  return XPCOMUtils.generateModule(components);
}
